import greenfoot.*;
public class Enemy extends Actor {
    // All the enemy instances use the
    // same GreenfootImage object to save
    // on memory. If the images were going
    // to be altered on an enemy-by-enemy
    // basis, this would have to change,
    // as currently a change to the image
    // of one enemy will alter it for all
    // of the enemies.
    private static final GreenfootImage
        ENEMY_IMAGE = new GreenfootImage("skull.png");
    private ScoreManager score;
    private int maxHealth;
    private int health;
    private int speed;
    private int value;
    
    public Enemy(ScoreManager score, int maxHealth, int speed, int value) {
        this.score = score;
        this.maxHealth = maxHealth;
        this.speed = speed;
        this.value = value;
        health = maxHealth;
        setImage(ENEMY_IMAGE);
    }
    
    public void act() {
        setLocation(getX() - speed, getY());
        checkPlayerCollision();
        checkIsOnScreen();
    }
    
    public void damage(int amount) {
        health -= amount;
        if(health <= 0) {
            score.add(value);
            getWorld().removeObject(this);
        } else {
            //healthBar.updateImage();
        }
    }
    
    private void checkPlayerCollision() {
        Player player = (Player)getOneIntersectingObject(Player.class);
        if(player != null) {
            getWorld().removeObject(player);
        }
    }
    
    private void checkIsOnScreen() {
        if(!isOnScreen()) {
            getWorld().removeObject(this);
        }
    }
    
    private boolean isOnScreen() {
        return getX() > 0;
    }
}
