import greenfoot.*;
import java.awt.Color;
public class Level extends MultipleLevelsWorld {
    protected ScoreManager score;
    private LevelInfo info;
    private int enemiesSpawned;
    
    public Level(LevelInfo info, ScoreManager score) {
        this.info = info;
        this.score = score;
        makeBackground();
        addPlayer();
    }
    
    public void act() {
        if(shouldSpawnEnemy()) {
            spawnEnemy();
        }
        if(isPlayerDead()) {
            Greenfoot.setWorld(new EndScreen(score, false));
        }
    }
    
    private void makeBackground() {
        GreenfootImage img = new GreenfootImage(getWidth(), getHeight());
        img.setColor(info.getBackgroundColor());
        img.fill();
        img.setColor(Color.BLACK);
        String levelName = getClass().getCanonicalName();
        img.drawString(levelName, 5, getHeight() - 6);
        setBackground(img);
    }
    
    private void addPlayer() {
        addObject(new Player(), 0, getHeight()/2);
    }
    
    private boolean shouldSpawnEnemy() {
        boolean enemiesLeftToSpawn = enemiesSpawned < info.getTotalEnemies();
        boolean randomChance = Greenfoot.getRandomNumber(100) < 6;
        return enemiesLeftToSpawn && randomChance;
    }
    
    private void spawnEnemy() {
        int x = getWidth();
        int y = Greenfoot.getRandomNumber(getHeight());
        Enemy enemy = new Enemy(score, info.getEnemyMaxHealth(), info.getEnemySpeed(), info.getEnemyValue());
        addObject(enemy, x, y);
        enemiesSpawned++;
    }
    
    protected boolean isLevelCompleted() {
        return enemiesSpawned == info.getTotalEnemies()
            && getObjects(Enemy.class).isEmpty();
    }
    
    protected boolean isPlayerDead() {
        return getObjects(Player.class).isEmpty();
    }
}
